==> haskell-onetuple-0.4.2-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-onetuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 OneTuple
version:              0.4.2
visibility:           public
id:                   OneTuple-0.4.2-DCyJUR8GMAF33aLYSt1izk
key:                  OneTuple-0.4.2-DCyJUR8GMAF33aLYSt1izk
license:              BSD-3-Clause
copyright:            (c) John Dorsey 2008
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, John Dorsey <haskell@colquitt.org>

author:               John Dorsey <haskell@colquitt.org>
stability:            experimental
synopsis:             Singleton Tuple
description:
    This package is a compatibility package for a singleton data type

    > data Solo a = MkSolo a

    Note: it'\''s not a @newtype@

    @Solo@ is available in @base-4.16@ (GHC-9.2).

category:             Data
abi:                  c23fe1bf51bd18f626b5c9bb5697e420
exposed:              True
exposed-modules:
    Data.Tuple.OneTuple Data.Tuple.Solo Data.Tuple.Solo.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-onetuple
hs-libraries:         HSOneTuple-0.4.2-DCyJUR8GMAF33aLYSt1izk
depends:
    base-4.17.2.1 ghc-prim-0.9.1 template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-onetuple/html/OneTuple.haddock
haddock-html:         /usr/share/doc/haskell-onetuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-onetuple-0.4.2-118-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-onetuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 OneTuple
version:              0.4.2
visibility:           public
id:                   OneTuple-0.4.2-2tzS8w4U7T42HVCT9nuDQM
key:                  OneTuple-0.4.2-2tzS8w4U7T42HVCT9nuDQM
license:              BSD-3-Clause
copyright:            (c) John Dorsey 2008
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, John Dorsey <haskell@colquitt.org>

author:               John Dorsey <haskell@colquitt.org>
stability:            experimental
synopsis:             Singleton Tuple
description:
    This package is a compatibility package for a singleton data type

    > data Solo a = MkSolo a

    Note: it'\''s not a @newtype@

    @Solo@ is available in @base-4.16@ (GHC-9.2).

category:             Data
abi:                  e236d3b94b96f47f6b80a9d14559ca7f
exposed:              True
exposed-modules:
    Data.Tuple.OneTuple Data.Tuple.Solo Data.Tuple.Solo.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-onetuple
hs-libraries:         HSOneTuple-0.4.2-2tzS8w4U7T42HVCT9nuDQM
depends:
    base-4.17.2.1 ghc-prim-0.9.1 template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-onetuple/html/OneTuple.haddock
haddock-html:         /usr/share/doc/haskell-onetuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
